@@ -8,7 +8,11 @@ void *mma_malloc(MM *, size_t);
 void  mma_free  (MM *, void *);
 int   mma_sizeok (void *ptr, const size_t usize);
 
-/* inline is removed if necessary by Makefile.PL */
+/* SGI compiler doesn't know inline */
+#if defined(_SGIAPI) || defined( __sgi )
+#define inline
+#endif
 inline int mma_alloc_mask(void);
 inline int mma_alloc_base(void);
+
 #endif /* _MMA_ALLOC_H_ */
